@@ -1,6 +1,6 @@
 from libifstate.util import logger, ipr, IfStateLogging
 from libifstate.exception import RouteDupblicate
-from ipaddress import ip_address, ip_network
+from ipaddress import ip_address, ip_network, IPv6Network
 from pyroute2.netlink.exceptions import NetlinkError
 from pyroute2.netlink.rtnl.fibmsg import FR_ACT_VALUES
 from pyroute2.netlink.rtnl import rt_type
@@ -13,17 +13,17 @@ import socket
 from socket import AF_INET, AF_INET6
 
 
-def route_matches(r1, r2, fields=('dst', 'priority', 'proto'), verbose=False, indent=""):
-    return _matches(r1, r2, fields, verbose, indent)
+def route_matches(r1, r2, fields=('dst', 'priority', 'proto'), indent=None):
+    return _matches(r1, r2, fields, indent)
 
 
-def rule_matches(r1, r2, fields=('priority', 'iif', 'oif', 'dst', 'metric', 'protocol'), verbose=False, indent=""):
-    return _matches(r1, r2, fields, verbose, indent)
+def rule_matches(r1, r2, fields=('priority', 'iif', 'oif', 'dst', 'metric', 'protocol'), indent=None):
+    return _matches(r1, r2, fields, indent)
 
 
-def _matches(r1, r2, fields, verbose, indent):
+def _matches(r1, r2, fields, indent):
     for fld in fields:
-        if verbose:
+        if not indent is None:
             logger.debug("{}: {} - {}".format(fld, r1.get(fld), r2.get(fld)), extra={'iface': indent})
         if fld in r1 and fld in r2:
             if r1[fld] != r2[fld]:
@@ -93,15 +93,15 @@ class Tables(collections.abc.Mapping):
         return len(self.tables)
 
     def add(self, route):
+        dst = ip_network(route['to'])
         rt = {
             'table': RTLookups.tables.lookup_id(route.get('table', 254)),
             'type': route.get('type', 'unicast'),
-            'dst': ip_network(route['to']).with_prefixlen,
+            'dst': dst.with_prefixlen,
             'scope': RTLookups.scopes.lookup_id(route.get('scope', 0)),
             'proto': RTLookups.protos.lookup_id(route.get('proto', 3)),
             'realm': RTLookups.realms.lookup_id(route.get('realm', 0)),
-            'tos': route.get('tos', 0),
-            'priority': 0
+            'tos': route.get('tos', 0)
         }
 
         if type(rt['type']) == str:
@@ -118,6 +118,10 @@ class Tables(collections.abc.Mapping):
 
         if 'preference' in route:
             rt['priority'] = route['preference']
+        elif isinstance(dst, IPv6Network):
+            rt['priority'] = 1024
+        else:
+            rt['priority'] = 0
 
         if not rt['table'] in self.tables:
             self.tables[rt['table']] = []
@@ -263,7 +267,7 @@ class Tables(collections.abc.Mapping):
                     if route_matches(route, kroute):
                         del kroutes[i]
                         found = True
-                        if route_matches(route, kroute, route.keys(), True, route['dst']):
+                        if route_matches(route, kroute, route.keys(), indent=route['dst']):
                             identical = True
                             break
 
@@ -306,35 +310,6 @@ class Tables(collections.abc.Mapping):
                         route['dst'], err.args[1]))
 
 
-class Routes():
-    def __init__(self):
-        self.routes = {}
-
-    def add(self, route):
-        dst = ip_network(route['dst'])
-        if dst in self.routes:
-            raise RouteDupblicate()
-
-        if 'table' in route:
-            route['table'] = RTLookups.tables.lookup_id(
-                route.get_attr('RTA_TABLE', 'main'))
-        # if 'dev' in route:
-        #     route['dev'] = xxxx
-        if 'scope' in route:
-            route['scope'] = RTLookups.scopes.lookup_id(route['scope'])
-
-        if 'proto' in route:
-            route['proto'] = RTLookups.protos.lookup_id(route['proto'])
-
-        if 'gateway' in route:
-            route['gateway'] = ip_address(route['gateway'])
-
-        if 'realm' in route:
-            route['realm'] = RTLookups.realms.lookup_id(route['realm'])
-
-        self.routes[dst] = route
-
-
 class Rules():
     def __init__(self):
         self.rules = []
